crystal_toolkit.components.transformations package — Crystal Toolkit documentation

# crystal_toolkit.components.transformations package

## Submodules

- crystal_toolkit.components.transformations.autooxistatedecoration module
- crystal_toolkit.components.transformations.core module
- crystal_toolkit.components.transformations.cubic module
- crystal_toolkit.components.transformations.grainboundary module
- crystal_toolkit.components.transformations.rattle module
- crystal_toolkit.components.transformations.slab module
- crystal_toolkit.components.transformations.substitution module
- crystal_toolkit.components.transformations.supercell module

## Module contents